fnss.traffic.eventscheduling.read_event_schedule — FNSS 0.6.1 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »

# fnss.traffic.eventscheduling.read_event_schedule

`read_event_schedule`(path)

  Read event schedule from an XML file

  Parameters: | path : str The path to the event schedule XML file
  Returns: | event_schedule : EventSchedule The parsed event schedule

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »